function [D_outer_el,D_outer_n,t_el,t_n,rho_el,rho_n,Emod_el,Emod_n,Gmod_el,Gmod_n,vP_el,vP_n,D_inner_el,D_inner_n,A_el,A_n,I_el,I_n,W_el,W_n,yield_strength_el,yield_strength_n] = ElementDimensions(FEA,S)
% Outer diameter
D_hydro = zeros(FEA.N_subm,1); % submerged elements outer diameter
for n = 0:1:(FEA.N_subm-1)
    if n*FEA.l_subm<=S.h_mp_taper
        D_hydro(FEA.N_subm-n,:) = S.D_mp_1;
    elseif n*FEA.l_subm<=S.h_tp_bottom
        D_hydro(FEA.N_subm-n,:) = S.D_mp_1 + S.taper_mp*(n*FEA.l_subm - S.h_mp_taper);
    elseif n*FEA.l_subm<=S.h_tp_taper
        D_hydro(FEA.N_subm-n,:) = S.D_tp_1 + S.taper_tp*(n*FEA.l_subm - S.h_tp_bottom);
    elseif n*FEA.l_subm<=S.h_tp_top
        D_hydro(FEA.N_subm-n,:) = S.D_tp_2;
    else
        error('Tower is submerged. TP length insufficient for safe design.')
    end
end

D_aero = zeros(FEA.N_unsubm,1); % unsubmerged elements outer diameter
for n = 0:1:(FEA.N_unsubm-1)
    if n*FEA.l_unsubm+(FEA.N_subm-1)*FEA.l_subm<=S.h_tp_taper
        D_aero(FEA.N_unsubm-n,:) = D_hydro(1,:)+S.taper_tp*n*FEA.l_unsubm;
    elseif n*FEA.l_unsubm+(FEA.N_subm-1)*FEA.l_subm<=S.h_tower_bottom
        D_aero(FEA.N_unsubm-n,:) = S.D_tower_1;
    elseif n*FEA.l_unsubm+(FEA.N_subm-1)*FEA.l_subm>S.h_tower_bottom
        D_aero(FEA.N_unsubm-n,:) = S.D_tower_1+S.taper_tower*(n*FEA.l_unsubm+(FEA.N_subm-1)*FEA.l_subm-S.h_tower_bottom);
    elseif n*FEA.l_unsubm+(FEA.N_subm-1)*FEA.l_subm>S.h_tower_top
        error('Faulty tower discretization. Elements of unequal length/sum of elements length larger than structural length.')
    else
        error('Tower is submerged. Reiterate design structure considering extreme wave height.')
    end
end

D_embed = zeros(FEA.N_embed,1); % embedded elements outer diameter
for n = 0:1:(FEA.N_embed-1)
    if n*FEA.l_embed+S.h_mp_bottom<=0
        D_embed(FEA.N_embed-n,:) = S.D_mp_1;
    else
        error('Pile embedment length and elements assigned as embedded inconsistent. Check discretization.')
    end
end

D_outer_n = [D_aero(1:end-1,:);D_hydro(1:end-1,:);D_embed(1:end,:)]; % [m] outer diameter at each node
D_outer_el = D_outer_n(1:end-1); % [m] outer diameter each element: diameter is assumed constant over element and equal to topmost node's diameter

% Thickness, density and moduli and Poisson ratio:
t_unsubm = zeros(FEA.N_unsubm,1); % thickness of the unsubmerged nodes
rho_unsubm = zeros(FEA.N_unsubm,1); % density of the unsubmerged nodes
Emod_unsubm = zeros(FEA.N_unsubm,1); % modulus of elasticity of the unsubmerged nodes
Gmod_unsubm = zeros(FEA.N_unsubm,1); % modulus of shear of the unsubmerged nodes
vP_unsubm = zeros(FEA.N_unsubm,1); % Poisson ratio of the unsubmerged nodes
yield_unsubm = zeros(FEA.N_unsubm,1); % Yield strength of the unsubmerged nodes
for n = 0:1:FEA.E_unsubm
    if (FEA.E_unsubm - n)*FEA.l_unsubm+FEA.E_subm*FEA.l_subm>=S.h_tower_bottom % tower section
        t_unsubm(n+1,:) = S.t_tower;
        rho_unsubm(n+1,:) = S.rho_tower;
        Emod_unsubm(n+1,:) = S.E_tower;
        Gmod_unsubm(n+1,:) = S.G_tower;
        vP_unsubm(n+1,:) = S.v_P_tower;
        yield_unsubm(n+1,:) = S.yield_strength_tower;
    elseif (FEA.E_unsubm - n)*FEA.l_unsubm+FEA.E_subm*FEA.l_subm>S.h_mp_top % tp section
        t_unsubm(n+1,:) = S.t_tp;
        rho_unsubm(n+1,:) = S.rho_tp;
        Emod_unsubm(n+1,:) = S.E_tp;
        Gmod_unsubm(n+1,:) = S.G_tp;
        vP_unsubm(n+1,:) = S.v_P_tp;
        yield_unsubm(n+1,:) = S.yield_strength_tp;
    elseif (FEA.E_unsubm - n)*FEA.l_unsubm+FEA.E_subm*FEA.l_subm>=S.h_tp_bottom % overlap section tp and mp
        t_unsubm(n+1,:) = S.t_tp+S.t_mp; % total thickness is the sum of mp, tp
        rho_unsubm(n+1,:) = (S.rho_tp*S.t_tp+S.rho_mp*S.t_mp)/(S.t_tp+S.t_mp); % approximation: assumed to be equal to the weighted average of mp, tp and grout
        Emod_unsubm(n+1,:) = (S.E_tp*S.t_tp+S.E_mp*S.t_mp)/(S.t_tp+S.t_mp); % approximation: assumed to be equal to the weighted average of mp, tp and grout
        Gmod_unsubm(n+1,:) = (S.G_tp*S.t_tp+S.G_mp*S.t_mp)/(S.t_tp+S.t_mp); % approximation: assumed to be equal to the weighted average of mp, tp and grout
        vP_unsubm(n+1,:) = (S.v_P_tp*S.t_tp+S.v_P_mp*S.t_mp)/(S.t_tp+S.t_mp); % approximation: assumed to be equal to the weighted average of mp, tp and grout
        yield_unsubm(n+1,:) = (S.yield_strength_tp*S.t_tp+S.yield_strength_mp*S.t_mp)/(S.t_tp+S.t_mp);
    elseif (FEA.E_unsubm - n)*FEA.l_unsubm+FEA.E_subm*FEA.l_subm>=0 % mp section above mudline
        t_unsubm(n+1,:) = S.t_mp;
        rho_unsubm(n+1,:) = S.rho_mp;
        Emod_unsubm(n+1,:) = S.E_mp;
        Gmod_unsubm(n+1,:) = S.G_mp;
        vP_unsubm(n+1,:) = S.v_P_mp;
        yield_unsubm(n+1,:) = S.yield_strength_mp;
    else
        error('Water level lies below mudline (unphysical). Check signs of parameters.')
    end
end

t_subm = zeros(FEA.N_subm,1); % thickness of the submerged nodes
rho_subm = zeros(FEA.N_subm,1); % density of the submerged nodes (only structural density considered)
Emod_subm = zeros(FEA.N_subm,1);
Gmod_subm = zeros(FEA.N_subm,1);
vP_subm = zeros(FEA.N_subm,1);
yield_subm = zeros(FEA.N_subm,1); % Yield strength of the submerged nodes
for n = 0:1:FEA.E_subm
    if (FEA.E_subm - n)*FEA.l_subm>=S.h_tower_bottom % tower section
        t_subm(n+1,:) = S.t_tower;
        rho_subm(n+1,:) = S.rho_tower;
        Emod_subm(n+1,:) = S.E_tower;
        Gmod_subm(n+1,:) = S.G_tower;
        vP_subm(n+1,:) = S.v_P_tower;
        yield_subm(n+1,:) = S.yield_strength_tower;
    elseif (FEA.E_subm - n)*FEA.l_subm>S.h_mp_top % tp section
        t_subm(n+1,:) = S.t_tp;
        rho_subm(n+1,:) = S.rho_tp;
        Emod_subm(n+1,:) = S.E_tp;
        Gmod_subm(n+1,:) = S.G_tp;
        vP_subm(n+1,:) = S.v_P_tp;
        yield_subm(n+1,:) = S.yield_strength_tp;
    elseif (FEA.E_subm - n)*FEA.l_subm>=S.h_tp_bottom % overlap tp and mp
        t_subm(n+1,:) = S.t_tp+S.t_mp;
        rho_subm(n+1,:) = (S.rho_tp*S.t_tp+S.rho_mp*S.t_mp)/(S.t_tp+S.t_mp);
        Emod_subm(n+1,:) = (S.E_tp*S.t_tp+S.E_mp*S.t_mp)/(S.t_tp+S.t_mp);
        Gmod_subm(n+1,:) = (S.G_tp*S.t_tp+S.G_mp*S.t_mp)/(S.t_tp+S.t_mp);
        vP_subm(n+1,:) = (S.v_P_tp*S.t_tp+S.v_P_mp*S.t_mp)/(S.t_tp+S.t_mp);
        yield_subm(n+1,:) = (S.yield_strength_tp*S.t_tp+S.yield_strength_mp*S.t_mp)/(S.t_tp+S.t_mp);
    elseif (FEA.E_subm - n)*FEA.l_subm>=0 % mp section above mudline
        t_subm(n+1,:) = S.t_mp;
        rho_subm(n+1,:) = S.rho_mp;
        Emod_subm(n+1,:) = S.E_mp;
        Gmod_subm(n+1,:) = S.G_mp;
        vP_subm(n+1,:) = S.v_P_mp;
        yield_subm(n+1,:) = S.yield_strength_mp;
    else
        error('Water level lies below mudline (unphysical). Check signs of parameters.')
    end
end

t_embed = zeros(FEA.N_embed,1); % thickness of the embedded nodes
rho_embed = zeros(FEA.N_embed,1); % density of the embedded nodes (structural density only, NOT including soil)
Emod_embed = zeros(FEA.N_embed,1);
Gmod_embed = zeros(FEA.N_embed,1);
vP_embed = zeros(FEA.N_embed,1);
yield_embed = zeros(FEA.N_embed,1); % Yield strength of the unsubmerged nodes
for n = 0:1:FEA.E_embed
    if (FEA.E_embed - n)*FEA.l_embed>abs(S.h_mp_bottom)
        error('Number of embedded elements exceed the embedded pile length. Check FEA discretization.')
    elseif (FEA.E_embed - n)*FEA.l_embed<=abs(S.h_mp_bottom) % mp section below mudline
        t_embed(n+1,:) = S.t_mp;
        rho_embed(n+1,:) = S.rho_mp;
        Emod_embed(n+1,:) = S.E_mp;
        Gmod_embed(n+1,:) = S.G_mp;
        vP_embed(n+1,:) = S.v_P_mp;
        yield_embed(n+1,:) = S.yield_strength_mp;
    end
end

t_n = [t_unsubm(1:end-1,:);t_subm(1:end-1,:);t_embed(1:end,:)]; % [m] thickness at each node
t_el = t_n(1:end-1,:); % [m] thickness assumed constant over length element and equal to topmost node's thickness

rho_n = [rho_unsubm(1:end-1,:);rho_subm(1:end-1,:);rho_embed(1:end,:)]; % [kg/m3] density at each node
rho_el = rho_n(1:end-1,:); % [kg/m3] density assumed constant over length element and equal to topmost node's 

Emod_n = [Emod_unsubm(1:end-1,:);Emod_subm(1:end-1,:);Emod_embed(1:end,:)]; % [Pa] Young's modulus at each node
Emod_el = Emod_n(1:end-1,:); % [Pa] Young's modulus assumed constant over length element and equal to topmost node's 

Gmod_n = [Gmod_unsubm(1:end-1,:);Gmod_subm(1:end-1,:);Gmod_embed(1:end,:)]; % [Pa] shear modulus at each node
Gmod_el = Gmod_n(1:end-1,:); % [Pa] shear modulus assumed constant over length element and equal to topmost node's 

vP_n = [vP_unsubm(1:end-1,:);vP_subm(1:end-1,:);vP_embed(1:end,:)]; % [-] Poisson ratio at each node
vP_el = vP_n(1:end-1,:); % [-] Poisson ratio assumed constant over length element and equal to topmost node's 

yield_strength_n = [yield_unsubm(1:end-1,:);yield_subm(1:end-1,:);yield_embed(1:end,:)]; 
yield_strength_el = yield_strength_n(1:end-1,:); 

% Inner diameter of each element:
D_inner_n = D_outer_n-2*t_n; % [m] diameter at each node
D_inner_el = D_outer_el-2*t_el; % [m] diameter assumed constant over element and equal to topmost node's

% Surface area of each element and node:
A_n = pi.*((D_outer_n./2).^2-(D_inner_n./2).^2); %[m2]
A_el = pi.*((D_outer_el./2).^2-(D_inner_el./2).^2); %[m2]

% Second area moment of inertia
I_n = pi/64*(D_outer_n.^4-D_inner_n.^4); %[m4]
I_el = pi/64*(D_outer_el.^4-D_inner_el.^4); %[m4]

% Plastic section modulus
W_n = 1/6.*D_outer_n.^3.*(1-(1-2.*t_n./D_outer_n).^3); %[m3]
W_el = 1/6.*D_outer_el.^3.*(1-(1-2.*t_el./D_outer_el).^3);


end