function [Mt_local,Mr_local] = LocalMassMatrix(FEA,DOF)
% Local mass matrix of each element
% Format 4 x 4 corresponding to [y1, theta1, y2, theta2]
% Assigned to one matrix, with every block of four rows corresponding to
% the local element matrix of one element.

% Translational mass matrix
Mt_local = zeros(FEA.E_total*2*DOF,2*DOF); % local element matrix
for i = 1:FEA.E_total
    % The local element matrix:
    Mt_local(4*i-3,:) = ((FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i))/((1+FEA.phifactor(i))^2))*[13/35+7*FEA.phifactor(i)/10+(FEA.phifactor(i)^2)/3, -(11/210+11*FEA.phifactor(i)/120+(FEA.phifactor(i)^2)/24)*FEA.L_el(i), 9/70+3*FEA.phifactor(i)/10+(FEA.phifactor(i)^2)/6, (13/420+3*FEA.phifactor(i)/40+(FEA.phifactor(i)^2)/24)*FEA.L_el(i)];
    Mt_local(4*i-2,:) = ((FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i))/((1+FEA.phifactor(i))^2))*[-(11/210+11*FEA.phifactor(i)/120+(FEA.phifactor(i)^2)/24)*FEA.L_el(i), (1/105+FEA.phifactor(i)/60+(FEA.phifactor(i)^2)/120)*FEA.L_el(i)^2, -(13/420+3*FEA.phifactor(i)/40+(FEA.phifactor(i)^2)/24)*FEA.L_el(i), -(1/140+FEA.phifactor(i)/60+(FEA.phifactor(i)^2)/120)*FEA.L_el(i)^2];
    Mt_local(4*i-1,:) = ((FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i))/((1+FEA.phifactor(i))^2))*[9/70+3*FEA.phifactor(i)/10+(FEA.phifactor(i)^2)/6, -(13/420+3*FEA.phifactor(i)/40+(FEA.phifactor(i)^2)/24)*FEA.L_el(i), 13/35+7*FEA.phifactor(i)/10+(FEA.phifactor(i)^2)/3, (11/210+11*FEA.phifactor(i)/120+(FEA.phifactor(i)^2)/24)*FEA.L_el(i)];
    Mt_local(4*i,:)   = ((FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i))/((1+FEA.phifactor(i))^2))*[(13/420+3*FEA.phifactor(i)/40+(FEA.phifactor(i)^2)/24)*FEA.L_el(i), -(1/140+FEA.phifactor(i)/60+(FEA.phifactor(i)^2)/120)*FEA.L_el(i)^2, (11/210+11*FEA.phifactor(i)/120+(FEA.phifactor(i)^2)/24)*FEA.L_el(i), (1/105+FEA.phifactor(i)/60+(FEA.phifactor(i)^2)/120)*FEA.L_el(i)^2];
end

% Rotational mass matrix
Mr_local = zeros(FEA.E_total*2*DOF,2*DOF); % local element matrix
for i = 1:FEA.E_total
    % The local element matrix:
    Mr_local(4*i-3,:) = FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i)/((1+FEA.phifactor(i))^2)*(sqrt(FEA.I_el(i)/FEA.A_el(i))/FEA.L_el(i))^2*[6/5, -(1/10-FEA.phifactor(i)/2)*FEA.L_el(i), -6/5, -(1/10-FEA.phifactor(i)/2)*FEA.L_el(i)];
    Mr_local(4*i-2,:) = FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i)/((1+FEA.phifactor(i))^2)*(sqrt(FEA.I_el(i)/FEA.A_el(i))/FEA.L_el(i))^2*[-(1/10-FEA.phifactor(i)/2)*FEA.L_el(i), (2/15+FEA.phifactor(i)/6+(FEA.phifactor(i)^2)/3)*FEA.L_el(i)^2, (1/10-FEA.phifactor(i)/2)*FEA.L_el(i), -(1/30+FEA.phifactor(i)/6-(FEA.phifactor(i)^2)/6)*FEA.L_el(i)^2];
    Mr_local(4*i-1,:) = FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i)/((1+FEA.phifactor(i))^2)*(sqrt(FEA.I_el(i)/FEA.A_el(i))/FEA.L_el(i))^2*[-6/5 (1/10-FEA.phifactor(i)/2)*FEA.L_el(i) 6/5 (1/10-FEA.phifactor(i)/2)*FEA.L_el(i)];
    Mr_local(4*i,:)   = FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i)/((1+FEA.phifactor(i))^2)*(sqrt(FEA.I_el(i)/FEA.A_el(i))/FEA.L_el(i))^2*[-(1/10-FEA.phifactor(i)/2)*FEA.L_el(i), -(1/30+FEA.phifactor(i)/6-(FEA.phifactor(i)^2)/6)*FEA.L_el(i)^2, (1/10-FEA.phifactor(i)/2)*FEA.L_el(i), (2/15+FEA.phifactor(i)/6+(FEA.phifactor(i)^2)/3)*FEA.L_el(i)^2];
end

% % Translational mass matrix
% Mt_local = zeros(FEA.E_total*2*DOF,2*DOF); % local element matrix
% for i = 1:FEA.E_total
%     % The local element matrix:
%     Mt_local(4*i-3,:) = ((FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i))/((1+FEA.phifactor(i))^2))*[13/35+7*FEA.phifactor(i)/10+(FEA.phifactor(i)^2)/3, (11/210+11*FEA.phifactor(i)/120+(FEA.phifactor(i)^2)/24)*FEA.L_el(i), 9/70+3*FEA.phifactor(i)/10+(FEA.phifactor(i)^2)/6, -(13/420+3*FEA.phifactor(i)/40+(FEA.phifactor(i)^2)/24)*FEA.L_el(i)];
%     Mt_local(4*i-2,:) = ((FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i))/((1+FEA.phifactor(i))^2))*[(11/210+11*FEA.phifactor(i)/120+(FEA.phifactor(i)^2)/24)*FEA.L_el(i), (1/105+FEA.phifactor(i)/60+(FEA.phifactor(i)^2)/120)*FEA.L_el(i)^2, (13/420+3*FEA.phifactor(i)/40+(FEA.phifactor(i)^2)/24)*FEA.L_el(i), -(1/140+FEA.phifactor(i)/60+(FEA.phifactor(i)^2)/120)*FEA.L_el(i)^2];
%     Mt_local(4*i-1,:) = ((FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i))/((1+FEA.phifactor(i))^2))*[9/70+3*FEA.phifactor(i)/10+(FEA.phifactor(i)^2)/6, (13/420+3*FEA.phifactor(i)/40+(FEA.phifactor(i)^2)/24)*FEA.L_el(i), 13/35+7*FEA.phifactor(i)/10+(FEA.phifactor(i)^2)/3, -(11/210+11*FEA.phifactor(i)/120+(FEA.phifactor(i)^2)/24)*FEA.L_el(i)];
%     Mt_local(4*i,:)   = ((FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i))/((1+FEA.phifactor(i))^2))*[-(13/420+3*FEA.phifactor(i)/40+(FEA.phifactor(i)^2)/24)*FEA.L_el(i), -(1/140+FEA.phifactor(i)/60+(FEA.phifactor(i)^2)/120)*FEA.L_el(i)^2, -(11/210+11*FEA.phifactor(i)/120+(FEA.phifactor(i)^2)/24)*FEA.L_el(i), (1/105+FEA.phifactor(i)/60+(FEA.phifactor(i)^2)/120)*FEA.L_el(i)^2];
% end
% 
% % Rotational mass matrix
% Mr_local = zeros(FEA.E_total*2*DOF,2*DOF); % local element matrix
% for i = 1:FEA.E_total
%     % The local element matrix:
%     Mr_local(4*i-3,:) = FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i)/((1+FEA.phifactor(i))^2)*(sqrt(FEA.I_el(i)/FEA.A_el(i))/FEA.L_el(i))^2*[6/5, (1/10-FEA.phifactor(i)/2)*FEA.L_el(i), -6/5, (1/10-FEA.phifactor(i)/2)*FEA.L_el(i)];
%     Mr_local(4*i-2,:) = FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i)/((1+FEA.phifactor(i))^2)*(sqrt(FEA.I_el(i)/FEA.A_el(i))/FEA.L_el(i))^2*[(1/10-FEA.phifactor(i)/2)*FEA.L_el(i), (2/15+FEA.phifactor(i)/6+(FEA.phifactor(i)^2)/3)*FEA.L_el(i)^2, -(1/10-FEA.phifactor(i)/2)*FEA.L_el(i), -(1/30+FEA.phifactor(i)/6-(FEA.phifactor(i)^2)/6)*FEA.L_el(i)^2];
%     Mr_local(4*i-1,:) = FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i)/((1+FEA.phifactor(i))^2)*(sqrt(FEA.I_el(i)/FEA.A_el(i))/FEA.L_el(i))^2*[-6/5 -(1/10-FEA.phifactor(i)/2)*FEA.L_el(i) 6/5 -(1/10-FEA.phifactor(i)/2)*FEA.L_el(i)];
%     Mr_local(4*i,:)   = FEA.rho_el(i)*FEA.A_el(i)*FEA.L_el(i)/((1+FEA.phifactor(i))^2)*(sqrt(FEA.I_el(i)/FEA.A_el(i))/FEA.L_el(i))^2*[(1/10-FEA.phifactor(i)/2)*FEA.L_el(i), -(1/30+FEA.phifactor(i)/6-(FEA.phifactor(i)^2)/6)*FEA.L_el(i)^2, -(1/10-FEA.phifactor(i)/2)*FEA.L_el(i), (2/15+FEA.phifactor(i)/6+(FEA.phifactor(i)^2)/3)*FEA.L_el(i)^2];
% end


end