function [Kb_local,Ks_local] = LocalStiffnessMatrix(FEA,DOF)
% Local bending matrix of each element
% Format 4 x 4 corresponding to [y1, theta1, y2, theta2]
% Assigned to one matrix, with every block of four rows corresponding to
% the local element matrix of one element.

% Bending stiffness
Kb_local = zeros(FEA.E_total*2*DOF,2*DOF); % local element matrix
for i = 1:FEA.E_total
    % The local element matrices:
    % for the displacement y at node 1
    Kb_local(4*i-3,:) = FEA.Emod_el(i)*FEA.I_el(i)/(FEA.L_el(i)^3*(1+FEA.phifactor(i))^2)*[12 -6*FEA.L_el(i) -12 -6*FEA.L_el(i)];
    % for the rotation theta at node 1
    Kb_local(4*i-2,:) = FEA.Emod_el(i)*FEA.I_el(i)/(FEA.L_el(i)^3*(1+FEA.phifactor(i))^2)*[-6*FEA.L_el(i) (4+2*FEA.phifactor(i)+FEA.phifactor(i)^2)*FEA.L_el(i)^2 6*FEA.L_el(i) (2-2*FEA.phifactor(i)-FEA.phifactor(i)^2)*FEA.L_el(i)^2];
    % for the displacement y at node 2
    Kb_local(4*i-1,:) = FEA.Emod_el(i)*FEA.I_el(i)/(FEA.L_el(i)^3*(1+FEA.phifactor(i))^2)*[-12 6*FEA.L_el(i) 12 6*FEA.L_el(i)];
    % for the rotation theta at node 2
    Kb_local(4*i,:)   = FEA.Emod_el(i)*FEA.I_el(i)/(FEA.L_el(i)^3*(1+FEA.phifactor(i))^2)*[-6*FEA.L_el(i) (2-2*FEA.phifactor(i)-FEA.phifactor(i)^2)*FEA.L_el(i)^2 6*FEA.L_el(i) (4+2*FEA.phifactor(i)+FEA.phifactor(i)^2)*FEA.L_el(i)^2];
end

% Shear stiffness
Ks_local = zeros(FEA.E_total*2*DOF,2*DOF); % local element matrix
for i = 1:FEA.E_total
    % The local element matrices:
    Ks_local(4*i-3,:) = (FEA.k_shear_el(i)*FEA.Gmod_el(i)*FEA.A_el(i)*((FEA.phifactor(i))^2))/(4*FEA.L_el(i)*((1+FEA.phifactor(i))^2))*[4 -2*FEA.L_el(i) -4 -2*FEA.L_el(i)];
    Ks_local(4*i-2,:) = (FEA.k_shear_el(i)*FEA.Gmod_el(i)*FEA.A_el(i)*((FEA.phifactor(i))^2))/(4*FEA.L_el(i)*((1+FEA.phifactor(i))^2))*[-2*FEA.L_el(i) FEA.L_el(i)^2 2*FEA.L_el(i) FEA.L_el(i)^2];
    Ks_local(4*i-1,:) = (FEA.k_shear_el(i)*FEA.Gmod_el(i)*FEA.A_el(i)*((FEA.phifactor(i))^2))/(4*FEA.L_el(i)*((1+FEA.phifactor(i))^2))*[-4 2*FEA.L_el(i) 4 2*FEA.L_el(i)];
    Ks_local(4*i,:)   = (FEA.k_shear_el(i)*FEA.Gmod_el(i)*FEA.A_el(i)*((FEA.phifactor(i))^2))/(4*FEA.L_el(i)*((1+FEA.phifactor(i))^2))*[-2*FEA.L_el(i) FEA.L_el(i)^2 2*FEA.L_el(i) FEA.L_el(i)^2];
end

% % Bending stiffness
% Kb_local = zeros(FEA.E_total*2*DOF,2*DOF); % local element matrix
% for i = 1:FEA.E_total
%     % The local element matrices:
%     % for the displacement y at node 1
%     Kb_local(4*i-3,:) = FEA.Emod_el(i)*FEA.I_el(i)/(FEA.L_el(i)^3*(1+FEA.phifactor(i))^2)*[12 6*FEA.L_el(i) -12 6*FEA.L_el(i)];
%     % for the rotation theta at node 1
%     Kb_local(4*i-2,:) = FEA.Emod_el(i)*FEA.I_el(i)/(FEA.L_el(i)^3*(1+FEA.phifactor(i))^2)*[6*FEA.L_el(i) (4+2*FEA.phifactor(i)+FEA.phifactor(i)^2)*FEA.L_el(i)^2 -6*FEA.L_el(i) (2-2*FEA.phifactor(i)-FEA.phifactor(i)^2)*FEA.L_el(i)^2];
%     % for the displacement y at node 2
%     Kb_local(4*i-1,:) = FEA.Emod_el(i)*FEA.I_el(i)/(FEA.L_el(i)^3*(1+FEA.phifactor(i))^2)*[-12 -6*FEA.L_el(i) 12 -6*FEA.L_el(i)];
%     % for the rotation theta at node 2
%     Kb_local(4*i,:)   = FEA.Emod_el(i)*FEA.I_el(i)/(FEA.L_el(i)^3*(1+FEA.phifactor(i))^2)*[6*FEA.L_el(i) (2-2*FEA.phifactor(i)-FEA.phifactor(i)^2)*FEA.L_el(i)^2 -6*FEA.L_el(i) (4+2*FEA.phifactor(i)+FEA.phifactor(i)^2)*FEA.L_el(i)^2];
% end
% 
% % Shear stiffness
% Ks_local = zeros(FEA.E_total*2*DOF,2*DOF); % local element matrix
% for i = 1:FEA.E_total
%     % The local element matrices:
%     Ks_local(4*i-3,:) = (FEA.k_shear_el(i)*FEA.Gmod_el(i)*FEA.A_el(i)*FEA.phifactor(i)^2)/(4*FEA.L_el(i)*(1+FEA.phifactor(i))^2)*[4 2*FEA.L_el(i) -4 2*FEA.L_el(i)];
%     Ks_local(4*i-2,:) = (FEA.k_shear_el(i)*FEA.Gmod_el(i)*FEA.A_el(i)*FEA.phifactor(i)^2)/(4*FEA.L_el(i)*(1+FEA.phifactor(i))^2)*[2*FEA.L_el(i) FEA.L_el(i)^2 -2*FEA.L_el(i) FEA.L_el(i)^2];
%     Ks_local(4*i-1,:) = (FEA.k_shear_el(i)*FEA.Gmod_el(i)*FEA.A_el(i)*FEA.phifactor(i)^2)/(4*FEA.L_el(i)*(1+FEA.phifactor(i))^2)*[-4 -2*FEA.L_el(i) 4 -2*FEA.L_el(i)];
%     Ks_local(4*i,:)   = (FEA.k_shear_el(i)*FEA.Gmod_el(i)*FEA.A_el(i)*FEA.phifactor(i)^2)/(4*FEA.L_el(i)*(1+FEA.phifactor(i))^2)*[2*FEA.L_el(i) FEA.L_el(i)^2 -2*FEA.L_el(i) FEA.L_el(i)^2];
% end

end