function [P1_minmargin,P1_maxmargin,P3_minmargin,P3_maxmargin] = P1P3_Resonance(FN,rpm_min,rpm_max)

%% Eigenfrequency check: 1P & 3P rotor frequency
% Check first natural frequency FN1 structure: 1P & 3P rotor resonance frequency bands
P1_min = rpm_min/60; %[Hz] Lower bound 1P frequency band 
P1_minmargin = P1_min*0.9; %[Hz] Lower bound 1P frequency band with 10% margin
P1_max = rpm_max/60;
P1_maxmargin = P1_max*1.1;

P3_min = 3*rpm_min/60; %[Hz] Lower bound 3P frequency band 
P3_minmargin = P3_min*0.9; %[Hz] Lower bound 3P frequency band with 10% margin
P3_max = 3*rpm_max/60;
P3_maxmargin = P3_max*1.1;

if FN(1) <= P1_maxmargin && FN(1) >= P1_minmargin
    error('Natural frequency structure within 1P resonance frequency band.')
elseif FN(1) < P1_minmargin
    error('Natural frequency structure within soft-soft frequency band.')
elseif FN(1) <= P3_maxmargin && FN(1) >= P3_minmargin
    error('Natural frequency structure within 3P resonance frequency band.')
elseif FN(1) > P3_maxmargin
    error('Natural frequency structure within stiff-stiff frequency band.')
else
    fprintf('This first eigenfrequency, %4.4f Hz, lies within the soft-stiff zone bounded by %4.4f Hz (1P +10%%) and %4.4f Hz (3P -10%%).\n',FN(1), P1_maxmargin, P3_minmargin)
end

%% Plot
frequencyband = figure;
plot([P1_minmargin P1_minmargin],[0 1],'-.', 'Color', [0.17 0.17 0.17]);
fvalue1=text(P1_minmargin,1.02,num2str(round(P1_minmargin,4)),'Color', [0.17 0.17 0.17],'Interpreter','Latex',...
    'Fontsize',11);
set(fvalue1,'Rotation',90);
hold on
plot([P1_maxmargin P1_maxmargin],[0 1],'-.', 'Color', [0.17 0.17 0.17]);
fvalue2=text(P1_maxmargin,1.02,num2str(round(P1_maxmargin,4)),'Color', [0.17 0.17 0.17],'Interpreter','Latex',...
    'Fontsize',11);
set(fvalue2,'Rotation',90);
hold on
plot([P1_minmargin P1_maxmargin],[1 1],'-.', 'Color', [0.17 0.17 0.17]);
hold on
plot([P1_min P1_min],[0 1],'-k');
hold on
plot([P1_max P1_max],[0 1],'-k');
hold on
plot([P1_min P1_max],[1 1],'-k');
txt1 = '1P';
text(0.9*(P1_max+P1_min)/2,0.8,txt1,'Color','black','Interpreter','Latex',...
    'Fontsize',11);
hold on
plot([P3_minmargin P3_minmargin],[0 1],'-.', 'Color', [0.17 0.17 0.17]);
fvalue4=text(P3_minmargin,1.02,num2str(round(P3_minmargin,4)),'Color', [0.17 0.17 0.17],'Interpreter','Latex',...
    'Fontsize',11);
set(fvalue4,'Rotation',90);
hold on
plot([P3_maxmargin P3_maxmargin],[0 1],'-.', 'Color', [0.17 0.17 0.17]);
fvalue3=text(P3_maxmargin,1.02,num2str(round(P3_maxmargin,4)),'Color', [0.17 0.17 0.17],'Interpreter','Latex',...
    'Fontsize',11);
set(fvalue3,'Rotation',90);
hold on
plot([P3_minmargin P3_maxmargin],[1 1],'-.', 'Color', [0.17 0.17 0.17]);
hold on
plot([P3_min P3_min],[0 1],'-k');
hold on
plot([P3_max P3_max],[0 1],'-k');
hold on
plot([P3_min P3_max],[1 1],'-k');
txt2 = '3P';
text((P3_max+P3_min)/2,0.8,txt2,'Color','black','Interpreter','Latex',...
    'Fontsize',11);
hold on
plot_FN = plot([FN(1) FN(1)],[0 1], '-k');
plot_FN.LineWidth = 1;
fvalueFN=text(FN(1),1.02,['\bf ', num2str(round(FN(1),4))],'Color', 'black','Interpreter','Latex',...
    'Fontsize',11);
set(fvalueFN,'Rotation',90);
hold on
txt3 = '\textit{soft-soft}';
text(0.01,0.06,txt3,'Color',[0.4 0.4 0.4],'Interpreter','Latex',...
    'Fontsize',11);
txt4 = '\textit{soft-stiff}';
text(0.23,0.06,txt4,'Color',[0.4 0.4 0.4],'Interpreter','Latex',...
    'Fontsize',11);
txt5 = '\textit{stiff-stiff}';
text(0.71,0.06,txt5,'Color',[0.4 0.4 0.4],'Interpreter','Latex',...
    'Fontsize',11);
set(gca,'TickLabelInterpreter','Latex','Fontsize',11)
set(gca,'ytick',[])
ylim([0 1.3]);
xlim([0 0.8]);
xlabel('Frequency $f$ [Hz]', 'Interpreter','Latex','Fontsize',11)
hold off
end