function [kf] = SoilStiffnessConstant(FEA,p,y)
% This function computes the soil reaction modulus based on the pile
% displacement and soil resistance per unit length. This value kf is equal
% to the spring value in the Winkler foundation model.

kf = gradient(p)./gradient(y);
for i = 1:FEA.N_total
    for j = 1:size(y,2)
        if i<=FEA.E_unsubm+FEA.N_subm
            if abs(kf(i,j))>0
                error('Soil clamping above mudline!')
            end
        end
        if sign(kf(i,j))==-1
            error('Negative soil stiffness!')
        end
        if isnan(kf(i,j))==1
            kf(i,j) = 0;
        end
    end
end
    
% kf = zeros(FEA.N_total,size(y,2)); % N_total x displacement format
% for i = (FEA.E_unsubm+FEA.E_subm+1+1):FEA.N_total % Only soil resistance below mudline, at mudline also zero
%     % The initial stiffness is equal to the SECANT modulus of the p-y curve
%     if size(y,2) == 1
%         kf(i,:) = p(i,:)./y(i,:);
%         for j = 1:size(y,2)
%             % Clear NaN values
%             if isnan(kf(i,j)) == 1
%                 kf(i,j) = 0;
%             end
%         end
%         for j = 1:size(y,2)-1
%             % Assume initial stiffness at origin is equal to linear stiffness,
%             % cannot be zero stiffness:
%             if isinf(kf(i,j+1)/kf(i,j))==1
%                 kf(i,j) = kf(i,j+1);
%             end
%         end
%     else
%         % The stiffness of the soil is equal to the TANGENT/GRADIENT of the p-y
%         % curve for a nonlinear soil material:
%         kf(i,:) = diffxy1(y(i,:),p(i,:));
%         for j = 1:size(y,2)
%             % Soil stiffness cannot be zero for computational stability reasons:
%             if kf(i,j)==0
%                 kf(i,j) = 1E-5;
%             end
%         end
%     end
% end
% end
% 
% 
