close all
clc
clear all

%% DLC-2: recorded earthquake
% load('SSI1_Recorded_Operational.mat')
% load('SSI2_Recorded_Operational.mat')
% load('SSI1_Recorded_Shutdown.mat')
% load('SSI2_Recorded_Shutdown.mat')
%% DLC-3: ELE earthquake
% load('SSI1_ELE_Operational.mat')
% load('SSI2_ELE_Operational.mat')
% load('SSI1_ELE_Shutdown.mat')
% load('SSI2_ELE_Shutdown.mat')
%% DLC-4: ALE earthquake
% load('SSI1_ALE_Operational.mat')
% load('SSI2_ALE_Operational.mat')
% load('SSI1_ALE_Shutdown.mat')
% load('SSI2_ALE_Shutdown.mat')

% Natural frequency progression due to dynamic loading 
FN = zeros(size(SOL.q_eq));
for j = 1:size(SOL.q_eq,2)
    % The generalized eigenvalue problem
    [V,D] = eig(SOL.M_global(:,:,j)\SOL.K_global(:,:,j)); % eigenvectors V and eigenvalues lamda D
    D_sort = sort(diag(D)); % eigenvalues lambda
    WN = sqrt(D_sort); % eigenvalues wn = sqrt(lambda) [rad/s]
    
    FN(:,j) = WN/(2*pi); % eigenfrequencies  
end

FN1 = FN(1,:);
FN1_max = max(FN1);
FN1_min = min(FN1);

% Natural frequency prior to dynamic loading
[Vs,Ds] = eig(FEA.M_global\FEA.K_global); % eigenvectors V and eigenvalues lamda D
D_sorts = sort(diag(Ds)); % eigenvalues lambda
WNs = sqrt(D_sorts); % eigenvalues wn = sqrt(lambda) [rad/s]

FNs = WNs/(2*pi); % eigenfrequencies
FN1_static = FNs(1);

%% Plot frequency progression first natural frequency in time
% with soil stiffness, pile displacement and total forces
% First, compute full hydro load (including added mass pile motion):
f_hydro = zeros(size(SOL.f_hydro));
for i = 1:1:FEA.N_total
    if i>FEA.E_unsubm && i<=FEA.N_total-FEA.E_embed % Enter submerged elements
        for j = 1:length(EQ.t)
            if (FEA.E_unsubm+FEA.N_subm-i)*FEA.l_subm<=DSS.d_hydro+DSS.eta(j)
                f_hydro(i,j) = SOL.f_hydro(i,j)-DSS.rho_hydro.*pi./4.*FEA.D_outer_el(i).^2.*DSS.CA.*SOL.ddydt_pile(i,j);
            end
        end
    end
end
% Integrate distributed external loads
[F_hydro,~] = Force_Moment(FEA,EQ.t,0,0,f_hydro);
[F_aero,~] = Force_Moment(FEA,EQ.t,0,0,SOL.f_aero);
T = WT.F_ad;

% Frequency
fig1 = figure;
s1 = subplot(5,1,1);
 p1 = plot(s1,EQ.t,FN1,'-b'); % SSI1
% p1 = plot(s1,EQ.t,FN1,'-m');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on','YMinorTick','on');
xlim([0 round(EQ.t(end))]);
xticks([0:10:round(EQ.t(end))]);
ylim([0 0.3]);
yticks([0 0.1 0.2 0.3]);
title(s1,'\textbf{First Natural Frequency}','Interpreter','Latex','Fontsize',13)
ylabel(s1,'Frequency [Hz]','Interpreter','Latex','Fontsize',13)
xlabel(s1,'Time [s]','Interpreter','Latex','Fontsize',13)
% Soil stiffness
s2 = subplot(5,1,2);
 p2 = plot(s2,EQ.t,SOL.kf(FEA.N_total,:),'-b');
% p2 = plot(s2,EQ.t,SOL.kf(FEA.N_total,:),'-m');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p2.LineWidth = 1;
set(gca, 'YGrid', 'on','YMinorTick','on');
xlim([0 round(EQ.t(end))]);
xticks([0:10:round(EQ.t(end))]);
title(s2,'\textbf{Soil Stiffness at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(s2,'Stiffness [N/m$^2$]','Interpreter','Latex','Fontsize',13)
xlabel(s2,'Time [s]','Interpreter','Latex','Fontsize',13)
% Pile displacement base
s3 = subplot(5,1,3);
 p3 = plot(s3,EQ.t,SOL.y_pile(FEA.N_total,:),'-b');
% p3 = plot(s3,EQ.t,SOL.y_pile(FEA.N_total,:),'-m');
p3.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on','YMinorTick','on');
xlim([0 round(EQ.t(end))]);
xticks([0:10:round(EQ.t(end))]);
title(s3,'\textbf{Structural Displacement at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(s3,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(s3,'Time [s]','Interpreter','Latex','Fontsize',13)
% Forces
s4 = subplot(5,1,4);
 p4 = plot(s4,EQ.t,F_hydro(FEA.N_unsubm+1,:)/1E3,'-b');
% p4 = plot(s4,EQ.t,F_hydro(FEA.N_unsubm+1,:)/1E3,'-m');
p4.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on','YMinorTick','on');
xlim([0 round(EQ.t(end))]);
xticks([0:10:round(EQ.t(end))]);
title(s4,'\textbf{Wave Forces}','Interpreter','Latex','Fontsize',13)
ylabel(s4,'Force [kN]','Interpreter','Latex','Fontsize',13)
xlabel(s4,'Time [s]','Interpreter','Latex','Fontsize',13)
% Earthquake ground motion
s5 = subplot(5,1,5);
 p5 = plot(s5,EQ.t,EQ.y_eq(FEA.N_total,:),'-b');
% p5 = plot(s5,EQ.t,EQ.y_eq(FEA.N_total,:),'-m');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on','YMinorTick','on');
xlim([0 round(EQ.t(end))]);
xticks([0:10:round(EQ.t(end))]);
title(s5,'\textbf{Earthquake Ground Motion at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(s5,'Ground motion [m]','Interpreter','Latex','Fontsize',13)
xlabel(s5,'Time [s]','Interpreter','Latex','Fontsize',13)
hold off

%% Eigenfrequency check: 1P & 3P rotor frequency
% Input 
rpm_min = WT.rpm_min;
rpm_max = WT.rpm_max;
% Check first natural frequency FN1 structure: 1P & 3P rotor resonance frequency bands
P1_min = rpm_min/60; %[Hz] Lower bound 1P frequency band 
P1_minmargin = P1_min*0.9; %[Hz] Lower bound 1P frequency band with 10% margin
P1_max = rpm_max/60;
P1_maxmargin = P1_max*1.1;

P3_min = 3*rpm_min/60; %[Hz] Lower bound 3P frequency band 
P3_minmargin = P3_min*0.9; %[Hz] Lower bound 3P frequency band with 10% margin
P3_max = 3*rpm_max/60;
P3_maxmargin = P3_max*1.1;

%% Plot
frequencyband = figure;
plot([P1_minmargin P1_minmargin],[0 1],'-.', 'Color', [0.17 0.17 0.17]);
fvalue1=text(P1_minmargin,1.02,num2str(round(P1_minmargin,4)),'Color', [0.17 0.17 0.17],'Interpreter','Latex',...
    'Fontsize',11);
set(fvalue1,'Rotation',90);
hold on
plot([P1_maxmargin P1_maxmargin],[0 1],'-.', 'Color', [0.17 0.17 0.17]);
fvalue2=text(P1_maxmargin,1.02,num2str(round(P1_maxmargin,4)),'Color', [0.17 0.17 0.17],'Interpreter','Latex',...
    'Fontsize',11);
set(fvalue2,'Rotation',90);
hold on
plot([P1_minmargin P1_maxmargin],[1 1],'-.', 'Color', [0.17 0.17 0.17]);
hold on
plot([P1_min P1_min],[0 1],'-k');
hold on
plot([P1_max P1_max],[0 1],'-k');
hold on
plot([P1_min P1_max],[1 1],'-k');
txt1 = '1P';
text(0.9*(P1_max+P1_min)/2,0.8,txt1,'Color','black','Interpreter','Latex',...
    'Fontsize',11);
hold on
plot([P3_minmargin P3_minmargin],[0 1],'-.', 'Color', [0.17 0.17 0.17]);
fvalue4=text(P3_minmargin,1.02,num2str(round(P3_minmargin,4)),'Color', [0.17 0.17 0.17],'Interpreter','Latex',...
    'Fontsize',11);
set(fvalue4,'Rotation',90);
hold on
plot([P3_maxmargin P3_maxmargin],[0 1],'-.', 'Color', [0.17 0.17 0.17]);
fvalue3=text(P3_maxmargin,1.02,num2str(round(P3_maxmargin,4)),'Color', [0.17 0.17 0.17],'Interpreter','Latex',...
    'Fontsize',11);
set(fvalue3,'Rotation',90);
hold on
plot([P3_minmargin P3_maxmargin],[1 1],'-.', 'Color', [0.17 0.17 0.17]);
hold on
plot([P3_min P3_min],[0 1],'-k');
hold on
plot([P3_max P3_max],[0 1],'-k');
hold on
plot([P3_min P3_max],[1 1],'-k');
txt2 = '3P';
text((P3_max+P3_min)/2,0.8,txt2,'Color','black','Interpreter','Latex',...
    'Fontsize',11);
hold on
plot_FN_max = plot([FN1_static FN1_static],[0 1], '-k');
plot_FN_max.LineWidth = 1;
fvalueFN=text(FN1_static,1.02,['\bf',num2str(round(FN1_static,4))],'Color', 'black','Interpreter','Latex',...
    'Fontsize',11);
set(fvalueFN,'Rotation',90);
hold on
newfn = plot([FN1_min FN1_min],[0 1],'-r');
hold on
plot([FN1_max FN1_max],[0 1],'-r');
hold on
plot([FN1_min FN1_max],[1 1],'-r');
txt_range = text(FN1_min-0.01,0.5,['\bf',num2str(round(FN1_min,4)), ' - ', num2str(round(FN1_max,4))],'Color', 'red','Interpreter','Latex',...
    'Fontsize',11);
set(txt_range,'Rotation',90);
legend([plot_FN_max,newfn],{'First natural frequency prior to loading','First natural frequency bounds after loading'}, 'Location','northeast','Interpreter','Latex','Fontsize',11);
hold on
txt3 = '\textit{soft-soft}';
text(0.01,0.06,txt3,'Color',[0.4 0.4 0.4],'Interpreter','Latex',...
    'Fontsize',11);
txt4 = '\textit{soft-stiff}';
text(0.23,0.06,txt4,'Color',[0.4 0.4 0.4],'Interpreter','Latex',...
    'Fontsize',11);
txt5 = '\textit{stiff-stiff}';
text(0.71,0.06,txt5,'Color',[0.4 0.4 0.4],'Interpreter','Latex',...
    'Fontsize',11);
set(gca,'TickLabelInterpreter','Latex','Fontsize',11)
set(gca,'ytick',[])
ylim([0 1.3]);
xlim([0 0.8]);
xlabel('Frequency $f$ [Hz]', 'Interpreter','Latex','Fontsize',11)
hold off
frequencyband.PaperUnits = 'centimeters';
frequencyband.PaperPosition = [0 0 25 10];

%% Tilt behaviour
% Tilt limit
tilt_limit = 0.5; % degree

% Identify largest deflected state
[r,c] = find(abs(SOL.y_pile)==max(max(abs(SOL.y_pile),[],2)));
y_state = SOL.y_pile(:,c); % m
t_state = EQ.t(c);

% Find pivot point deflected state about new balance position after GM
diff = y_state - EQ.y_eq(:,c);
index = (FEA.E_unsubm+FEA.E_subm)+knnsearch(diff((FEA.N_unsubm+FEA.E_subm):end),0); % should be a point below mudline!!
pivot = interp1([diff(index-1) diff(index) diff(index+1)],[FEA.H_n(index-1) FEA.H_n(index) FEA.H_n(index+1)],0);
balance = interp1([FEA.H_n(index-1) FEA.H_n(index) FEA.H_n(index+1)],[EQ.y_eq(index-1,c) EQ.y_eq(index,c) EQ.y_eq(index+1,c)],pivot);

% Normalize new balance position to zero
y_state = y_state - balance;

% Calculate tilt angle displacement state
tilt = zeros(size(y_state));
for i = 1:FEA.N_total
    tilt(i,:) = atand((y_state(i))./(FEA.H_n(i) - pivot)); % degree
end

% Calculate displacement limit
y_limit = tand(tilt_limit).*(FEA.H_n - pivot); % m


% Displacement limit plot
displacement_limit = figure;
hp = plot(y_state+balance, FEA.H_n, 'k');
hp.LineWidth = 1;
hold on
patch([balance balance y_limit(1)+balance -y_limit(1)+balance], [pivot pivot, FEA.H_n(1) FEA.H_n(1)], [0.5 0.8 0.5],'FaceAlpha',.5)
hp = plot(y_state+balance, FEA.H_n, 'k');
hp.LineWidth = 1;
hold on
hp2 = plot(y_state+balance, FEA.H_n, 'k');
hp2.LineWidth = 1;
hold on
patch([balance balance y_limit(end)+balance -y_limit(end)+balance], [pivot pivot, FEA.H_n(end) FEA.H_n(end)], [0.5 0.8 0.5],'FaceAlpha',.5)
hp2 = plot(y_state+balance, FEA.H_n, 'k');
hp2.LineWidth = 1;
% xlim([-1.5 1.5]); % for NSS
% xlim([-1 3]); % for EQ, operational
% xlim([-4 2]); % for EQ, shutdown
% xlim([-3 7]); % for ELE, operational
% xlim([-9 2]); % for ELE, shutdown
% xlim([-5 12]); % for ALE, operational
xlim([-15 1]); % for ALE, shutdown
ylim([FEA.H_n(end) FEA.H_n(1)]);
ylabel('Height [m]', 'Interpreter','Latex','Fontsize',18);
xlabel('Displacement [m]', 'Interpreter','Latex','Fontsize',18);
set(gca,'YMinorTick','on','TickLabelInterpreter','Latex','Fontsize',18)
hold on
% pivotline = plot([-1.5,1.5], [pivot pivot], ':k'); % for NSS
% pivotline = plot([-1,3], [pivot pivot], ':k'); % for EQ, operational
% pivotline = plot([-4,2], [pivot pivot], ':k'); % for EQ, shutdown
% pivotline = plot([-3,7], [pivot pivot], ':k'); % for ELE, operational
% pivotline = plot([-9,2], [pivot pivot], ':k'); % for ELE, shutdown
% pivotline = plot([-5,12], [pivot pivot], ':k');
pivotline = plot([-15,1], [pivot pivot], ':k');
pivotline.LineWidth = 1.5;
hold on
nodeflect = plot([0,0], [-45 120], ':k');
nodeflect.LineWidth = 1.5;
hold on
% mudline = plot([-1.5,1.5], [0 0], 'Color',[0.4,0,0]); % NSS
% mudline = plot([-1,3], [0 0], 'Color',[0.4,0,0]); % for EQ, operational
% mudline = plot([-4,2], [0 0], 'Color',[0.4,0,0]); % for EQ, shutdown
% mudline = plot([-3,7], [0 0], 'Color',[0.4,0,0]); % for ELE, operational
% mudline = plot([-9,2], [0 0], 'Color',[0.4,0,0]); % for ELE, shutdown
% mudline = plot([-5,12], [0 0], 'Color',[0.4,0,0]);
mudline = plot([-15,1], [0 0], 'Color',[0.4,0,0]);
mudline.LineWidth = 1;
hold off

% Angle limit plot
tiltlimit = figure;
hp = plot(tilt, FEA.H_n, 'k');
hp.LineWidth = 1;
hold on
patch([-tilt_limit tilt_limit tilt_limit -tilt_limit], [FEA.H_n(end) FEA.H_n(end) FEA.H_n(1) FEA.H_n(1)], [0.5 0.8 0.5],'FaceAlpha',.5)
hp = plot(tilt, FEA.H_n, 'k');
hp.LineWidth = 1;
hold on
% xlim([-1.5 1.5]);
% xlim([-3 3]); % for ELE, operational
% xlim([-4 4]); % for ELE, shutdown
xlim([-6 6]); % for ALE, shutdown
ylim([FEA.H_n(end) FEA.H_n(1)]);
ylabel('Height [m]', 'Interpreter','Latex','Fontsize',18);
xlabel('Angle [$^{\circ}$]', 'Interpreter','Latex','Fontsize',18);
set(gca,'YMinorTick','on','TickLabelInterpreter','Latex','Fontsize',18)
hold on
% pivotline = plot([-1.5,1.5], [pivot pivot], ':k');
% pivotline = plot([-3,3], [pivot pivot], ':k'); % ELE, operational
% pivotline = plot([-4,4], [pivot pivot], ':k'); % ELE, shutdown
pivotline = plot([-6,6], [pivot pivot], ':k');
pivotline.LineWidth = 1.5;
hold on
nodeflect = plot([0,0], [-45 120], ':k');
nodeflect.LineWidth = 1.5;
hold on
% mudline = plot([-1.5,1.5], [0 0], 'Color',[0.4,0,0]);
% mudline = plot([-3,3], [0 0], 'Color',[0.4,0,0]);
% mudline = plot([-4,4], [0 0], 'Color',[0.4,0,0]);
mudline = plot([-6,6], [0 0], 'Color',[0.4,0,0]);
mudline.LineWidth = 1;
hold off

%% Yield check
% Initialize
F = zeros(size(f_hydro));
M = zeros(size(F));
triang_forces = zeros(size(F,1)-1,size(F,2));
rect_forces = zeros(size(F,1)-1,size(F,2));
triang_arm = zeros(size(F,1)-1,size(F,1)-1);
rect_arm = zeros(size(F,1)-1,size(F,1)-1);
MT = zeros(size(F));
% The distributed loads
loads = f_hydro+SOL.f_aero-SOL.kf.*SOL.y_pile;
% At the topmost node, the force and moment are equal to the point force
% (thrust) and moment (zero)
F0 = WT.T;
M0 = 0;
F(1,:) = F0;
M(1,:) = M0;

%Initialize moment arm
for i = 1:FEA.E_total
    triang_arm(i,i) = 2/3*FEA.L_el(i);
    rect_arm(i,i) = 1/2*FEA.L_el(i);
end
% Calculate moment arm for each node
for i = 1:FEA.E_total
    for k = (i+1):FEA.E_total
        if i~=k   
            triang_arm(i,k) = triang_arm(i,k-1)+FEA.L_el(k);
            rect_arm(i,k) = rect_arm(i,k-1)+FEA.L_el(k);
        end
    end
end

for j = 1:size(F,2)
    for i = 2:FEA.N_total
        triang_forces(i-1,j) = 0.5.*FEA.L_el(i-1).*(loads(i-1,j)-loads(i,j));
        rect_forces(i-1,j) = FEA.L_el(i-1).*loads(i,j);
        F(i,j) = F(i-1,j) + triang_forces(i-1,j) + rect_forces(i-1,j);
    end
end

triang_moment = triang_forces'*triang_arm; % format t x nodes
rect_moment = rect_forces'*rect_arm; % format t x nodes

for j = 1:size(F,2)
    for i = 2:FEA.N_total
        MT(i,j) = MT(i-1,j)+F0*FEA.L_el(i-1);
        M(i,j) = M0+MT(i,j)+triang_moment(j,i-1)+rect_moment(j,i-1); % Moment due to top point force and top moment
        
    end
end

SF_yield = 1.1; % safety factor for material (1.1)
[sigma_calc,sigma_yield,UR,SF] = YieldCheck(FEA,SF_yield,FM.P_axial,M);

yield_check = figure;
hp = plot(max(abs(UR),[],2), FEA.H_n, 'k');
hp.LineWidth = 1;
hold on
patch([0 1 1 0], [FEA.H_n(end) FEA.H_n(end) FEA.H_n(1) FEA.H_n(1)], [0.5 0.8 0.5],'FaceAlpha',.5)
hp = plot(max(abs(UR),[],2), FEA.H_n, 'k');
hp.LineWidth = 1;
hold on
% xlim([0 1.2]); % NSS
%  xlim([0 3]); % EQ, operational
% xlim([0 4]); % EQ, shutdown
%  xlim([0 6.5]); % ELE, operational
xlim([0 10]);
ylim([FEA.H_n(end) FEA.H_n(1)]);
ylabel('Height [m]', 'Interpreter','Latex','Fontsize',18);
xlabel('Utilisation ratio $\frac{\sigma}{\sigma_y}$ [-]', 'Interpreter','Latex','Fontsize',18);
set(gca,'YMinorTick','on','TickLabelInterpreter','Latex','Fontsize',18)
hold on
% MP = plot([0 1.2], [S.h_tp_bottom S.h_tp_bottom], ':k'); % no EQ
%  MP = plot([0 3], [S.h_tp_bottom S.h_tp_bottom], ':k'); % EQ, operational
% MP = plot([0 4], [S.h_tp_bottom S.h_tp_bottom], ':k'); % EQ, shutdown
% MP = plot([0 6.5], [S.h_tp_bottom S.h_tp_bottom], ':k'); % ELE, operational
MP = plot([0 10], [S.h_tp_bottom S.h_tp_bottom], ':k');
% text(1.02,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
%    'Fontsize',16); % no Eq
% text(2.5,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
%    'Fontsize',16); % EQ, operational
% text(5.6,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
%    'Fontsize',16); % ELE, operational
text(8,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
   'Fontsize',16); % ALE
%  text(3.2,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
%      'Fontsize',16); % EQ, shutdown
MP.LineWidth = 1.5;
hold on
% TPMP = plot([0 1.2], [S.h_mp_top S.h_mp_top], ':k');
%  TPMP = plot([0 3], [S.h_mp_top S.h_mp_top], ':k');
% TPMP = plot([0 4], [S.h_mp_top S.h_mp_top], ':k');
% TPMP = plot([0 6.5], [S.h_mp_top S.h_mp_top], ':k');
TPMP = plot([0 10], [S.h_mp_top S.h_mp_top], ':k');
TPMP.LineWidth = 1.5;
% text(1.02,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
%    'Fontsize',16);
% text(2.5,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
%    'Fontsize',16);
%  text(3.2,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
%      'Fontsize',16);
% text(5.6,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
%    'Fontsize',16);
text(8,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
   'Fontsize',16);
hold on
% TP = plot([0 1.2], [S.h_tp_top S.h_tp_top], ':k');
%  TP = plot([0 3], [S.h_tp_top S.h_tp_top], ':k');
% TP = plot([0 4], [S.h_tp_top S.h_tp_top], ':k');
% TP = plot([0 6.5], [S.h_tp_top S.h_tp_top], ':k');
TP = plot([0 10], [S.h_tp_top S.h_tp_top], ':k');
TP.LineWidth = 1.5;
% text(1.02,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% text(2.5,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
%    'Fontsize',16);
%  text(3.2,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
%      'Fontsize',16);
% text(5.6,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
%    'Fontsize',16);
text(8,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
   'Fontsize',16);
hold on
% TWR = plot([0 1.2], [S.h_tower_bottom S.h_tower_bottom], ':k');
%  TWR = plot([0 3], [S.h_tower_bottom S.h_tower_bottom], ':k');
% TWR = plot([0 4], [S.h_tower_bottom S.h_tower_bottom], ':k');
% TWR = plot([0 6.5], [S.h_tower_bottom S.h_tower_bottom], ':k');
TWR = plot([0 10], [S.h_tower_bottom S.h_tower_bottom], ':k');
% text(1.02,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% text(2.5,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
%    'Fontsize',16);
%  text(3.2,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
%      'Fontsize',16);
% text(5.6,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
%    'Fontsize',16);
text(8,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
   'Fontsize',16);
TWR.LineWidth = 1.5;
hold on
% mudline = plot([0 1.2], [0 0], 'Color',[0.4,0,0]);
%  mudline = plot([0 3], [0 0], 'Color',[0.4,0,0]);
% mudline = plot([0 4], [0 0], 'Color',[0.4,0,0]);
% mudline = plot([0 6.5], [0 0], 'Color',[0.4,0,0]);
mudline = plot([0 10], [0 0], 'Color',[0.4,0,0]);
mudline.LineWidth = 1;
hold off


yield_check_absolute = figure;
hp = plot(max(abs(sigma_calc),[],2)/1E6, FEA.H_n, 'k');
hp.LineWidth = 1;
hold on
patch([0 sigma_yield(1,1)/1E6 sigma_yield(1,1)/1E6 0], [FEA.H_n(end) FEA.H_n(end) FEA.H_n(1) FEA.H_n(1)], [0.5 0.8 0.5],'FaceAlpha',.5)
hp = plot(max(abs(sigma_calc),[],2)/1E6, FEA.H_n, 'k');
hp.LineWidth = 1;
hold on
% xlim([0 450]);
%  xlim([0 1000]); % EQ, operational
% xlim([0 1500]);
%  xlim([0 2500]); % ELE, operational
xlim([0 3000]);
ylim([FEA.H_n(end) FEA.H_n(1)]);
ylabel('Height [m]', 'Interpreter','Latex','Fontsize',18);
xlabel('Yield stress $\sigma$ [MPa]', 'Interpreter','Latex','Fontsize',18);
set(gca,'YMinorTick','on','TickLabelInterpreter','Latex','Fontsize',18)
hold on
% MP = plot([0 450], [S.h_tp_bottom S.h_tp_bottom], ':k');
% MP.LineWidth = 0.65;
% text(360,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% MP = plot([0 1000], [S.h_tp_bottom S.h_tp_bottom], ':k');
% MP.LineWidth = 1.5;
% text(850,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% MP = plot([0 1500], [S.h_tp_bottom S.h_tp_bottom], ':k');
% MP.LineWidth = 0.65;
% text(1200,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% MP = plot([0 2500], [S.h_tp_bottom S.h_tp_bottom], ':k');
% MP.LineWidth = 1.5;
% text(2000,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
MP = plot([0 3000], [S.h_tp_bottom S.h_tp_bottom], ':k');
MP.LineWidth = 1.5;
text(2500,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
    'Fontsize',16);
hold on
% TPMP = plot([0 450], [S.h_mp_top S.h_mp_top], ':k');
% TPMP.LineWidth = 0.65;
% text(360,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TPMP = plot([0 1000], [S.h_mp_top S.h_mp_top], ':k');
% TPMP.LineWidth = 1.5;
% text(850,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TPMP = plot([0 1500], [S.h_mp_top S.h_mp_top], ':k');
% TPMP.LineWidth = 0.65;
% text(1200,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TPMP = plot([0 2500], [S.h_mp_top S.h_mp_top], ':k');
% TPMP.LineWidth = 1.5;
% text(2000,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
TPMP = plot([0 3000], [S.h_mp_top S.h_mp_top], ':k');
TPMP.LineWidth = 1.5;
text(2500,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
    'Fontsize',16);
hold on
% TP = plot([0 450], [S.h_tp_top S.h_tp_top], ':k');
% TP.LineWidth = 0.65;
% text(360,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TP = plot([0 1000], [S.h_tp_top S.h_tp_top], ':k');
% TP.LineWidth = 1.5;
% text(850,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TP = plot([0 1500], [S.h_tp_top S.h_tp_top], ':k');
% TP.LineWidth = 0.65;
% text(1200,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TP = plot([0 2500], [S.h_tp_top S.h_tp_top], ':k');
% TP.LineWidth = 1.5;
% text(2000,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
TP = plot([0 3000], [S.h_tp_top S.h_tp_top], ':k');
TP.LineWidth = 1.5;
text(2500,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
    'Fontsize',16);
hold on
% TWR = plot([0 450], [S.h_tower_bottom S.h_tower_bottom], ':k');
% TWR.LineWidth = 0.65;
% text(360,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TWR = plot([0 1000], [S.h_tower_bottom S.h_tower_bottom], ':k');
% TWR.LineWidth = 1.5;
% text(850,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TWR = plot([0 1500], [S.h_tower_bottom S.h_tower_bottom], ':k');
% TWR.LineWidth = 0.65;
% text(1200,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TWR = plot([0 2500], [S.h_tower_bottom S.h_tower_bottom], ':k');
% TWR.LineWidth = 1.5;
% text(2000,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
TWR = plot([0 3000], [S.h_tower_bottom S.h_tower_bottom], ':k');
TWR.LineWidth = 1.5;
text(2500,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
    'Fontsize',16);
hold on
% mudline = plot([0 450], [0 0], 'Color',[0.4,0,0]);
%  mudline = plot([0 1000], [0 0], 'Color',[0.4,0,0]);
% mudline = plot([0 1500], [0 0], 'Color',[0.4,0,0]);
% mudline = plot([0 2500], [0 0], 'Color',[0.4,0,0]);
mudline = plot([0 3000], [0 0], 'Color',[0.4,0,0]);
mudline.LineWidth = 1;
hold off

%% Buckling check
% Buckling moment factor
bm = 0.66; % zero top moment clamped beam
%
Ne = pi^2.*FEA.Emod_n.*FEA.I_n./(1.1.*(2.1.*S.L_total).^2);
% Reduced slenderness
l = sqrt(FEA.A_n.*sigma_yield./Ne);
% Material factor
for i = 1:FEA.N_total
    if l(i)<=0.5
        gm = 1.10;
    elseif l(i)<1
        gm = 0.8+0.6*l(i);
    elseif l(i)>=1
        gm = 1.40;
    end
end
%
phi = 0.5.*(1+0.21.*(l-0.2)+l.^2);
%
kappa = zeros(size(l));
for i = 1:FEA.N_total
    if l(i)>0.2
        kappa(i) = 1./(phi(i)+sqrt(phi(i).^2-l(i).^2));
    else
        kappa(i) = 1;
    end
end
% 
delta = 0.25.*kappa.*l.^2;
for i = 1:FEA.N_total
    if delta(i)>=0.1
        delta(i) = 0.1;
    end
end
% Plastic moment and normal force
Mp = FEA.W_n.*sigma_yield./gm;
Np = FEA.A_n.*sigma_yield./gm;
% Normal force
N = [FM.P_axial;0];
% Buckling state
BCKL = zeros(size(M));
for j = 1:size(M,2)
BCKL(:,j) = N./(kappa.*Np)+bm.*M(:,j)./Mp+delta;
end
% Safety factor for buckling of shells
SF_buckling = 1.2;
BCKL = BCKL./SF_buckling;

buckling_check = figure;
hp = plot(max(abs(BCKL),[],2), FEA.H_n, 'k');
hp.LineWidth = 1;
hold on
patch([0 1 1 0], [FEA.H_n(end) FEA.H_n(end) FEA.H_n(1) FEA.H_n(1)], [0.5 0.8 0.5],'FaceAlpha',.5)
hp = plot(max(abs(BCKL),[],2), FEA.H_n, 'k');
hp.LineWidth = 1;
hold on
% xlim([0 1.2]);
% xlim([0 2]); %EQ
% xlim([0 3]); %ELE
xlim([0 5]); %ALE
ylim([FEA.H_n(end) FEA.H_n(1)]);
ylabel('Height [m]', 'Interpreter','Latex','Fontsize',18);
xlabel('Buckling ratio [-]', 'Interpreter','Latex','Fontsize',18);
set(gca,'YMinorTick','on','TickLabelInterpreter','Latex','Fontsize',18)
hold on
% MP = plot([0 1.2], [S.h_tp_bottom S.h_tp_bottom], ':k');
% MP.LineWidth = 0.65;
% text(1.02,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% MP = plot([0 2], [S.h_tp_bottom S.h_tp_bottom], ':k');
% MP.LineWidth = 1.5;
% text(1.5,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% MP = plot([0 3], [S.h_tp_bottom S.h_tp_bottom], ':k');
% MP.LineWidth = 1.5;
% text(2.5,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
MP = plot([0 5], [S.h_tp_bottom S.h_tp_bottom], ':k');
MP.LineWidth = 1.5;
text(4.2,S.h_mp_bottom+(S.h_tp_bottom-S.h_mp_bottom)/2,'MP','Color', 'black','Interpreter','Latex',...
    'Fontsize',16);
hold on
% TPMP = plot([0 1.2], [S.h_mp_top S.h_mp_top], ':k');
% TPMP.LineWidth = 0.65;
% text(1.02,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TPMP = plot([0 2], [S.h_mp_top S.h_mp_top], ':k');
% TPMP.LineWidth = 1.5;
% text(1.5,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TPMP = plot([0 3], [S.h_mp_top S.h_mp_top], ':k');
% TPMP.LineWidth = 1.5;
% text(2.5,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
TPMP = plot([0 5], [S.h_mp_top S.h_mp_top], ':k');
TPMP.LineWidth = 1.5;
text(4.2,S.h_tp_bottom+(S.h_mp_top-S.h_tp_bottom)/2,'TP+MP','Color', 'black','Interpreter','Latex',...
    'Fontsize',16);
hold on
% TP = plot([0 1.2], [S.h_tp_top S.h_tp_top], ':k');
% TP.LineWidth = 0.65;
% text(1.02,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TP = plot([0 2], [S.h_tp_top S.h_tp_top], ':k');
% TP.LineWidth = 1.5;
% text(1.5,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TP = plot([0 3], [S.h_tp_top S.h_tp_top], ':k');
% TP.LineWidth = 1.5;
% text(2.5,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
TP = plot([0 5], [S.h_tp_top S.h_tp_top], ':k');
TP.LineWidth = 1.5;
text(4.2,S.h_mp_top+(S.h_tp_top-S.h_mp_top)/2,'TP','Color', 'black','Interpreter','Latex',...
    'Fontsize',16);
hold on
% TWR = plot([0 1.2], [S.h_tower_bottom S.h_tower_bottom], ':k');
% TWR.LineWidth = 0.65;
% text(1.02,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TWR = plot([0 2], [S.h_tower_bottom S.h_tower_bottom], ':k');
% TWR.LineWidth = 1.5;
% text(1.5,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
% TWR = plot([0 3], [S.h_tower_bottom S.h_tower_bottom], ':k');
% TWR.LineWidth = 1.5;
% text(2.5,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
%     'Fontsize',16);
TWR = plot([0 5], [S.h_tower_bottom S.h_tower_bottom], ':k');
TWR.LineWidth = 1.5;
text(4.2,S.h_tp_top+(S.h_tower_top-S.h_tp_top)/2,'Tower','Color', 'black','Interpreter','Latex',...
    'Fontsize',16);
hold on
% mudline = plot([0 1.2], [0 0], 'Color',[0.4,0,0]);
% mudline = plot([0 2], [0 0], 'Color',[0.4,0,0]);
% mudline = plot([0 3], [0 0], 'Color',[0.4,0,0]);
mudline = plot([0 5], [0 0], 'Color',[0.4,0,0]);
mudline.LineWidth = 1;
hold off

