%% CREATE PLOTS FOR REPORT
% Load beam model
load('SSI1_NSS_Operational.mat','FEA');

% 1) PILE DISPLACEMENT HISTORY
% A) NO EARTHQUAKE LOADING
% OPERATIONAL ROTOR
% #Time series
load('SSI1_NSS_Operational.mat','EQ','SOL');
PLOT.t = EQ.t;
% #Pile displacements
% Operational condition DLC1 (No EQ) - SSI1
PLOT.y_pile_SSI1_OP_DLC1 = SOL.y_pile;
clear SOL
clear EQ
% Operational condition DLC1 (No EQ) - SSI2
load('SSI2_NSS_Operational.mat','SOL');
PLOT.y_pile_SSI2_OP_DLC1 = SOL.y_pile;
clear SOL
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.91 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_OP_DLC1(1,:),'-b');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 90]);
%ylim([-0.6 0.6]);
%yticks([-0.5 0 0.5]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p2 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_OP_DLC1(1,:),'-.m');
p2.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
hold off
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .91 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_OP_DLC1(FEA.N_unsubm+1,:),'-b');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 90]);
%ylim([-0.6 0.6]);
%yticks([-0.5 0 0.5]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p4 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_OP_DLC1(FEA.N_unsubm+1,:),'-.m');
p4.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
hold off
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .91 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_OP_DLC1(FEA.N_total,:),'-b');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 90]);
%ylim([-0.6 0.6]);
%yticks([-0.5 0 0.5]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p6 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_OP_DLC1(FEA.N_total,:),'-.m');
p6.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
hold off

% SHUTDOWN
% #Time series
load('SSI1_NSS_Shutdown.mat','SOL');
% #Pile displacements
% Operational condition DLC1 (No EQ) - SSI1
PLOT.y_pile_SSI1_SD_DLC1 = SOL.y_pile;
clear SOL
% Operational condition DLC1 (No EQ) - SSI2
load('SSI2_NSS_Shutdown.mat','SOL');
PLOT.y_pile_SSI2_SD_DLC1 = SOL.y_pile;
clear SOL
% #At RNA node
fig2 = figure('DefaultAxesPosition', [0.01, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.91 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_SD_DLC1(1,:),'-b');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
%ylim([-0.6 0.6]);
%yticks([-0.5 0 0.5]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p2 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_SD_DLC1(1,:),'-.m');
p2.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
hold off
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .91 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_SD_DLC1(FEA.N_unsubm+1,:),'-b');
p3.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
%ylim([-0.6 0.6]);
%yticks([-0.5 0 0.5]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p4 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_SD_DLC1(FEA.N_unsubm+1,:),'-.m');
p4.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
hold off
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .91 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_SD_DLC1(FEA.N_total,:),'-b');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
%ylim([-0.6 0.6]);
%yticks([-0.5 0 0.5]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p6 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_SD_DLC1(FEA.N_total,:),'-.m');
p6.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
hold off

%% B) RECORDED EARTHQUAKE LOADING
% OPERATIONAL ROTOR

% SSI1 vs SSI2
% #Time series
load('SSI1_Recorded_Operational.mat','EQ','SOL');
PLOT.t = EQ.t;
% #Ground motion
PLOT.y_eq_DLC2 = EQ.y_eq;
clear EQ
% #Pile displacements
% Operational condition DLC1 (No EQ) - SSI1
PLOT.y_pile_SSI1_OP_DLC2 = SOL.y_pile;
clear SOL
% Operational condition DLC1 (No EQ) - SSI2
load('SSI2_Recorded_Operational.mat','SOL');
PLOT.y_pile_SSI2_OP_DLC2 = SOL.y_pile;
clear SOL
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_OP_DLC2(1,:),'-b');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p2 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_OP_DLC2(1,:),'-m');
p2.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_OP_DLC2(FEA.N_unsubm+1,:),'-b');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p4 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_OP_DLC2(FEA.N_unsubm+1,:),'-m');
p4.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_OP_DLC2(FEA.N_total,:),'-b');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p6 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_OP_DLC2(FEA.N_total,:),'-m');
p6.LineWidth = 1;
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC2(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI1','SSI2','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SSI1
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_OP_DLC2(1,:),'-b');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI1'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_OP_DLC2(FEA.N_unsubm+1,:),'-b');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI1'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_OP_DLC2(FEA.N_total,:),'-b');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC2(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI1','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SSI2
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_OP_DLC2(1,:),'-m');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_OP_DLC2(FEA.N_unsubm+1,:),'-m');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_OP_DLC2(FEA.N_total,:),'-m');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC2(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI2','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SHUTDOWN
% OPERATIONAL ROTOR
% SSI1 vs SSI2
% #Time series
load('SSI1_Recorded_Shutdown.mat','EQ','SOL');
PLOT.t = EQ.t;
% #Ground motion
PLOT.y_eq_DLC2 = EQ.y_eq;
clear EQ
% #Pile displacements
% Operational condition DLC1 (No EQ) - SSI1
PLOT.y_pile_SSI1_SD_DLC2 = SOL.y_pile;
clear SOL
% Operational condition DLC1 (No EQ) - SSI2
load('SSI2_Recorded_Shutdown.mat','SOL');
PLOT.y_pile_SSI2_SD_DLC2 = SOL.y_pile;
clear SOL
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_SD_DLC2(1,:),'-b');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p2 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_SD_DLC2(1,:),'-m');
p2.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_SD_DLC2(FEA.N_unsubm+1,:),'-b');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p4 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_SD_DLC2(FEA.N_unsubm+1,:),'-m');
p4.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_SD_DLC2(FEA.N_total,:),'-b');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p6 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_SD_DLC2(FEA.N_total,:),'-m');
p6.LineWidth = 1;
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC2(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI1','SSI2','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SSI1
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_SD_DLC2(1,:),'-b');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI1'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_SD_DLC2(FEA.N_unsubm+1,:),'-b');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI1'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_SD_DLC2(FEA.N_total,:),'-b');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC2(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI1','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SSI2
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_SD_DLC2(1,:),'-m');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_SD_DLC2(FEA.N_unsubm+1,:),'-m');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_SD_DLC2(FEA.N_total,:),'-m');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC2(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI2','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

%% C) ELE LOADING
% OPERATIONAL ROTOR

% SSI1 vs SSI2
% #Time series
load('SSI1_ELE_Operational.mat','EQ','SOL');
PLOT.t = EQ.t;
% #Ground motion
PLOT.y_eq_DLC3 = EQ.y_eq;
clear EQ
% #Pile displacements
% Operational condition DLC1 (No EQ) - SSI1
PLOT.y_pile_SSI1_OP_DLC3 = SOL.y_pile;
clear SOL
% Operational condition DLC1 (No EQ) - SSI2
load('SSI2_ELE_Operational.mat','SOL');
PLOT.y_pile_SSI2_OP_DLC3 = SOL.y_pile;
clear SOL
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_OP_DLC3(1,:),'-b');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p2 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_OP_DLC3(1,:),'-m');
p2.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_OP_DLC3(FEA.N_unsubm+1,:),'-b');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p4 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_OP_DLC3(FEA.N_unsubm+1,:),'-m');
p4.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_OP_DLC3(FEA.N_total,:),'-b');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p6 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_OP_DLC3(FEA.N_total,:),'-m');
p6.LineWidth = 1;
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC3(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI1','SSI2','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SSI1
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_OP_DLC3(1,:),'-b');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI1'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_OP_DLC3(FEA.N_unsubm+1,:),'-b');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI1'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_OP_DLC3(FEA.N_total,:),'-b');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC3(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI1','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SSI2
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_OP_DLC3(1,:),'-m');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_OP_DLC3(FEA.N_unsubm+1,:),'-m');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_OP_DLC3(FEA.N_total,:),'-m');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC3(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI2','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SHUTDOWN
% OPERATIONAL ROTOR
% SSI1 vs SSI2
% #Time series
load('SSI1_ELE_Shutdown.mat','EQ','SOL');
PLOT.t = EQ.t;
% #Ground motion
PLOT.y_eq_DLC3 = EQ.y_eq;
clear EQ
% #Pile displacements
% Operational condition DLC1 (No EQ) - SSI1
PLOT.y_pile_SSI1_SD_DLC3 = SOL.y_pile;
clear SOL
% Operational condition DLC1 (No EQ) - SSI2
load('SSI2_ELE_Shutdown.mat','SOL');
PLOT.y_pile_SSI2_SD_DLC3 = SOL.y_pile;
clear SOL
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_SD_DLC3(1,:),'-b');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p2 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_SD_DLC3(1,:),'-m');
p2.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_SD_DLC3(FEA.N_unsubm+1,:),'-b');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p4 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_SD_DLC3(FEA.N_unsubm+1,:),'-m');
p4.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_SD_DLC3(FEA.N_total,:),'-b');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p6 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_SD_DLC3(FEA.N_total,:),'-m');
p6.LineWidth = 1;
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC3(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI1','SSI2','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SSI1
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_SD_DLC3(1,:),'-b');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI1'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_SD_DLC3(FEA.N_unsubm+1,:),'-b');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI1'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_SD_DLC3(FEA.N_total,:),'-b');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC3(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI1','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SSI2
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_SD_DLC3(1,:),'-m');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_SD_DLC3(FEA.N_unsubm+1,:),'-m');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_SD_DLC3(FEA.N_total,:),'-m');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC3(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI2','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

%% D) ALE LOADING

% OPERATIONAL ROTOR

% SSI1 vs SSI2
% #Time series
load('SSI1_ALE_Operational.mat','EQ','SOL');
PLOT.t = EQ.t;
% #Ground motion
PLOT.y_eq_DLC4 = EQ.y_eq;
clear EQ
% #Pile displacements
% Operational condition DLC1 (No EQ) - SSI1
PLOT.y_pile_SSI1_OP_DLC4 = SOL.y_pile;
clear SOL
% Operational condition DLC1 (No EQ) - SSI2
load('SSI2_ALE_Operational.mat','SOL');
PLOT.y_pile_SSI2_OP_DLC4 = SOL.y_pile;
clear SOL
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_OP_DLC4(1,:),'-b');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p2 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_OP_DLC4(1,:),'-m');
p2.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_OP_DLC4(FEA.N_unsubm+1,:),'-b');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p4 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_OP_DLC4(FEA.N_unsubm+1,:),'-m');
p4.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_OP_DLC4(FEA.N_total,:),'-b');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p6 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_OP_DLC4(FEA.N_total,:),'-m');
p6.LineWidth = 1;
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC4(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI1','SSI2','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SSI1
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_OP_DLC4(1,:),'-b');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI1'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_OP_DLC4(FEA.N_unsubm+1,:),'-b');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI1'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_OP_DLC4(FEA.N_total,:),'-b');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC4(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI1','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SSI2
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_OP_DLC4(1,:),'-m');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_OP_DLC4(FEA.N_unsubm+1,:),'-m');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_OP_DLC4(FEA.N_total,:),'-m');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC4(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI2','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SHUTDOWN
% OPERATIONAL ROTOR
% SSI1 vs SSI2
% #Time series
load('SSI1_ALE_Shutdown.mat','EQ','SOL');
PLOT.t = EQ.t;
% #Ground motion
PLOT.y_eq_DLC4 = EQ.y_eq;
clear EQ
% #Pile displacements
% Operational condition DLC1 (No EQ) - SSI1
PLOT.y_pile_SSI1_SD_DLC4 = SOL.y_pile;
clear SOL
% Operational condition DLC1 (No EQ) - SSI2
load('SSI2_ELE_Shutdown.mat','SOL');
PLOT.y_pile_SSI2_SD_DLC4 = SOL.y_pile;
clear SOL
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_SD_DLC4(1,:),'-b');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p2 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_SD_DLC4(1,:),'-m');
p2.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_SD_DLC4(FEA.N_unsubm+1,:),'-b');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p4 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_SD_DLC4(FEA.N_unsubm+1,:),'-m');
p4.LineWidth = 1;
legend({'SSI1','SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_SD_DLC4(FEA.N_total,:),'-b');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p6 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_SD_DLC4(FEA.N_total,:),'-m');
p6.LineWidth = 1;
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC4(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI1','SSI2','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SSI1
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI1_SD_DLC4(1,:),'-b');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI1'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI1_SD_DLC4(FEA.N_unsubm+1,:),'-b');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI1'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI1_SD_DLC4(FEA.N_total,:),'-b');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC4(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI1','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off

% SSI2
% #At RNA node
fig1 = figure('DefaultAxesPosition', [0.05, 0.01, 0.98, 0.98]);
OE_RNA = subplot(3,1,1);
set(OE_RNA, 'Position', [0.08 0.72 0.75 .23]);
p1 = plot(OE_RNA,PLOT.t,PLOT.y_pile_SSI2_SD_DLC4(1,:),'-m');
axP = get(gca,'Position');
p1.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_RNA,'\textbf{Node at RNA}','Interpreter','Latex','Fontsize',13)
ylabel(OE_RNA,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_RNA,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node just below SWL
OE_SWL = subplot(3,1,2);
set(OE_SWL, 'Position', [0.08 0.39 .75 .23]);
p3 = plot(OE_SWL,PLOT.t,PLOT.y_pile_SSI2_SD_DLC4(FEA.N_unsubm+1,:),'-m');
axP = get(gca,'Position');
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
p3.LineWidth = 1;
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_SWL,'\textbf{Node below MWL}','Interpreter','Latex','Fontsize',13)
ylabel(OE_SWL,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_SWL,'Time [s]','Interpreter','Latex','Fontsize',13)
legend({'SSI2'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
% #At node below mudline
OE_MUD = subplot(3,1,3);
set(OE_MUD, 'Position', [0.08 0.06 .75 .23]);
p5 = plot(OE_MUD,PLOT.t,PLOT.y_pile_SSI2_SD_DLC4(FEA.N_total,:),'-m');
axP = get(gca,'Position');
p5.LineWidth = 1;
set(gca,'TickLabelInterpreter','Latex','Fontsize',13);
set(gca, 'YGrid', 'on' );
xlim([0 150]);
%ylim([-0.6 0.6]);
xticks([0:10:150]);
title(OE_MUD,'\textbf{Node at Pile Base}','Interpreter','Latex','Fontsize',13)
ylabel(OE_MUD,'Displacement [m]','Interpreter','Latex','Fontsize',13)
xlabel(OE_MUD,'Time [s]','Interpreter','Latex','Fontsize',13)
hold on
p7 = plot(OE_MUD,PLOT.t,PLOT.y_eq_DLC4(FEA.N_total,:),'--c'); % EQ signal
p7.LineWidth = 1;
legend({'SSI2','Ground Motion'},'Location','bestoutside','Interpreter','Latex','Fontsize',13)
set(gca, 'Position', axP);
hold off
