%% FEA: NODES AND ELEMENTS

FEA.E_total = FEA.E_embed+FEA.E_subm+FEA.E_unsubm;


% Nodes per structural section
FEA.N_embed = FEA.E_embed+1;                                                % Number of nodes = elements+1
FEA.N_subm = FEA.E_subm+1;
FEA.N_unsubm = FEA.E_unsubm+1;
FEA.N_total = FEA.E_embed+FEA.E_subm+FEA.E_unsubm+1;

%% ELEMENT DIMENSIONS AND STRUCTURAL PROPERTIES
% Length of the elements
FEA.l_embed = S.L_mp_emb/FEA.E_embed;                                       % [m]
FEA.l_subm = (max(DSS.eta)+DSS.d_hydro)/FEA.E_subm;                         % [m] section classified as submerged if inundated at maximum WL
FEA.l_unsubm = (S.h_tower_top-(max(DSS.eta)+DSS.d_hydro))/FEA.E_unsubm;     % [m]

% Vector containing nodal heights wrt reference frame:
FEA.H_n = [transpose(S.h_tower_top:-FEA.l_unsubm:(max(DSS.eta)+...
    DSS.d_hydro));transpose((max(DSS.eta)+DSS.d_hydro-FEA.l_subm):...
    -FEA.l_subm:0);transpose((0-FEA.l_embed):-FEA.l_embed:S.h_mp_bottom)];  % [m] 

% Vector containing element lengths:
FEA.L_el = [FEA.l_unsubm*ones(FEA.E_unsubm,1);FEA.l_subm*ones(FEA.E_subm,1);...
    FEA.l_embed*ones(FEA.E_embed,1)];                                       % [m]

% Diameter (outer) of the elements and at the nodes, thickness of the 
% elements and at the nodes, density,Young's modulus of elasticity, shear 
% modulus, Poisson ratio, diameter (inner), area, second moment of inertia:
[FEA.D_outer_el,FEA.D_outer_n,FEA.t_el,FEA.t_n,FEA.rho_el,FEA.rho_n,...
    FEA.Emod_el,FEA.Emod_n,FEA.Gmod_el,FEA.Gmod_n,FEA.vP_el,FEA.vP_n,...
    FEA.D_inner_el,FEA.D_inner_n,FEA.A_el,FEA.A_n,FEA.I_el,...
    FEA.I_n,FEA.W_el,FEA.W_n,FEA.yield_strength_el,FEA.yield_strength_n]...
    = ElementDimensions(FEA,S);                                             % [m], [m], [m], [m], [kg/m3], [kg/m3], [Pa], [Pa], [Pa], [Pa], [-], [-], [m], [m], [m2], [m2], [m4], [m4]
