%% LOCAL AND GLOBAL MATRICES FEM

% LOCAL MATRICES
% Mass - Translational and rotation:
[FEA.Mt_local,FEA.Mr_local] = LocalMassMatrix(FEA,DOF);
% Do not forget to add water body hydrodynamic added mass
for i = 1:1:FEA.E_total
    if i>FEA.E_unsubm && i<=FEA.E_total-FEA.E_embed % Enter submerged elements
        if (FEA.E_unsubm+FEA.N_subm-i)*FEA.l_subm<=DSS.d_hydro+DSS.eta(1)
            FEA.Mt_local(i*DOF*2-3,1) = FEA.Mt_local(i*DOF*2-3,1) + DSS.rho_hydro*pi/4*FEA.D_outer_el(i)^2*DSS.CA;
            FEA.Mt_local(i*DOF*2-1,3) = FEA.Mt_local(i*DOF*2-1,3) + DSS.rho_hydro*pi/4*FEA.D_outer_el(i)^2*DSS.CA;
        end
    end
end

% Stiffness - Bending and shear:
[FEA.Kb_local,FEA.Ks_local] = LocalStiffnessMatrix(FEA,DOF);

% Stiffness - Geometric overlying elements and element:
[FM.P_axial,FEA.Kg0_local,FEA.Kg_local] = LocalGeometricStiffnessMatrix(g,WT,FEA,DOF);

% Stiffness - Soil initial stiffness prior to loading:
y_1 = G.y(1,2) - G.y(1,1);                                                  % [m] Elastic displacement
tic
for i = 1:FEA.N_total
    GI = griddedInterpolant(G.y(i,:),G.kf_pycurve(i,:));
    FEA.kf(i,:) = GI(y_1);
end
toc
[FEA.Kf_local] = LocalSoilStiffnessMatrix(FEA,FEA.kf,DOF);                  % Local soil stiffness matrix prior to loading
% ===========================================================================================================================================================
% GLOBAL MATRICES
% Mass
[FEA.Mt_global] = GlobalMatrix(FEA,FEA.Mt_local,DOF);                       % Translational global mass matrix
[FEA.Mr_global] = GlobalMatrix(FEA,FEA.Mr_local,DOF);                       % Rotational global mass matrix
FEA.Mt_global(1,1) = FEA.Mt_global(1,1) + WT.M_RNA;                         % Add top mass RNA
FEA.M_global = FEA.Mt_global+FEA.Mr_global;                                 % Total mass matrix

% Stiffness
[FEA.Kb_global] = GlobalMatrix(FEA,FEA.Kb_local,DOF);                       % Bending global stiffness matrix
[FEA.Ks_global] = GlobalMatrix(FEA,FEA.Ks_local,DOF);                       % Shear global stiffness matrix
[FEA.Kf_global] = GlobalMatrix(FEA,FEA.Kf_local,DOF);                       % Foundation global stiffness matrix
[FEA.Kg_global] = GlobalMatrix(FEA,FEA.Kg_local,DOF);                       % Geometric element global stiffness matrix
[FEA.Kg0_global] = GlobalMatrix(FEA,FEA.Kg0_local,DOF);                     % Geometric structure global stiffness matrix
FEA.K_global = FEA.Kb_global+FEA.Ks_global+FEA.Kf_global-FEA.Kg_global-FEA.Kg0_global; % Total stiffness matrix

% Damping
FEA.C_global = zeros(FEA.N_total*DOF,FEA.N_total*DOF);                      % Ignore system damping, no soil damping in SSI1

clear y_1 GI
%% NATURAL FREQUENCY - EIGENVALUE PROBLEM
% Compute the natural frequencies of the system:
[FN,~,MODAL.PHI] = NaturalFrequency(FEA.M_global,FEA.K_global,MODAL.NumberOfModeShapes);

% Verify if the first natural frequency lies clear of the 1P and 3P rotor
% frequency (avoid resonance with rotor operation). This function also
% creates a plot:
[WT.P1_minmargin,WT.P1_maxmargin,WT.P3_minmargin,WT.P3_maxmargin] = P1P3_Resonance(FN,WT.rpm_min,WT.rpm_max);

%% ROTOR OPERATIONAL PARAMETERS - THRUST AND DAMPING
Wind_Turbine

%% PROCESS EARTHQUAKE DATA FOR IMPLEMENTATION IN ODE
Earthquake_Processing